@@ -27,31 +27,27 @@
 #' @import dplyr
 #' @importFrom rlang quo_text
 #' @examples
-#' library(fingertipsR)
 #' library(dplyr)
-#' region <- "South East region"
-#' top_names <- c("England", region)
+#' df <- create_test_data()
+#' parent <- "PAC11"
+#' top_names <- c("C001", parent)
 #' ordered_levels <- c("Better",
 #'                     "Similar",
 #'                     "Worse",
 #'                     "Not compared")
-#' df <- fingertips_data(90316) %>%
-#'         filter(is.na(CategoryType) &
-#'                        Timeperiod == "2016/17" &
-#'                        (AreaName %in% top_names |
-#'                                 ParentName == region) &
-#'                        Sex == "Persons") %>%
-#'         mutate(ComparedtoEnglandvalueorpercentiles =
-#'                        factor(ComparedtoEnglandvalueorpercentiles,
-#'                               levels = ordered_levels))
-#' p <- compare_areas(df, AreaName, Value,
-#'                    fill = ComparedtoEnglandvalueorpercentiles,
-#'                    lowerci = LowerCI95.0limit,
-#'                    upperci = UpperCI95.0limit,
+#' df_ca <- df %>%
+#'         filter(IndicatorName == "Indicator 3",
+#'                (AreaCode %in% top_names |
+#'                         ParentAreaCode == parent))
+#' p <- compare_areas(df_ca, AreaCode, Value,
+#'                    fill = Significance,
+#'                    lowerci = LCI,
+#'                    upperci = UCI,
 #'                    order = "desc",
 #'                    top_areas = top_names,
-#'                    title = unique(df$IndicatorName))
+#'                    title = "Compare the local areas")
 #' p
+#'
 #' @export
 compare_areas <- function(data, area, value,
                           lowerci, upperci,
@@ -138,7 +134,7 @@ compare_areas <- function(data, area, value,
                 fill <- enquo(fill)
                 compare_areas <- compare_areas +
                         geom_col(aes_string(fill = quo_text(fill))) +
-                        scale_fill_phe(name = "Area compared to England",
+                        scale_fill_phe(name = "Area compared to Benchmark",
                                        theme = "fingertips")
 
         } else {
@@ -178,6 +174,7 @@ compare_areas <- function(data, area, value,
                 theme_phe("fingertips") +
                 theme(legend.position = legend.position,
                       panel.grid.major.y = element_blank())
+        return(compare_areas)
 }
 
 #' Plot an overview (tartan rug) of multiple indicators
@@ -198,21 +195,23 @@ compare_areas <- function(data, area, value,
 #' @importFrom rlang quo_text
 #' @importFrom stringr str_wrap
 #' @examples
-#' library(fingertipsR)
 #' library(dplyr)
-#' region <- "North East region"
-#' top_names <- c("England", region)
-#' dfdom <- fingertips_data(DomainID = 1938133060) %>%
-#'         filter(Timeperiod == "2016",
-#'                Age == "All ages",
-#'                (AreaName %in% top_names | ParentName == region)) %>%
+#' df <- create_test_data()
+#'
+#' parent <- "PAC14"
+#' top_names <- c("C001", parent)
+#' df_over <- df %>%
+#'         filter((AreaCode %in% top_names |
+#'                         ParentAreaCode == parent)) %>%
 #'         mutate(Value = round(Value, 1))
-#' p <- overview(dfdom,
-#'               area = AreaName,
+#' p <- overview(df_over,
+#'               area = AreaCode,
 #'               indicator = IndicatorName,
 #'               value = Value,
-#'               fill = ComparedtoEnglandvalueorpercentiles,
-#'               top_areas = top_names, wrap_length = 40,
+#'               timeperiod = Timeperiod,
+#'               fill = Significance,
+#'               top_areas = top_names,
+#'               wrap_length = 40,
 #'               value_label_size = 0.8)
 #' p
 #' @export
@@ -289,6 +288,7 @@ overview <- function(data, area, indicator, value,
                       axis.title = element_blank(),
                       line = element_blank(),
                       rect = element_blank())
+        return(overview)
 }
 
 #' Plot compare indicators plot
@@ -308,28 +308,27 @@ overview <- function(data, area, indicator, value,
 #' @importFrom rlang quo_text
 #' @importFrom stats lm as.formula
 #' @examples
-#' \donttest{
-#' # This example is untested because of the time required to retrieve the data
-#' library(fingertipsR)
-#' library(dplyr)
 #' library(tidyr)
-#' df <- fingertips_data(c(90362, 90366)) %>%
-#'         group_by(IndicatorID) %>%
-#'         filter(Timeperiod == "2014 - 16" &
-#'                        Sex == "Female",
-#'                        Age == "All ages") %>%
-#'         ungroup() %>%
-#'         select(IndicatorID, AreaName, Value) %>%
-#'         mutate(IndicatorID = paste0("x", IndicatorID)) %>%
-#'         spread(IndicatorID, Value)
-#' p <- compare_indicators(df,
-#'                         x = x90362,
-#'                         y = x90366,
-#'                         xlab = "Healthy life expectancy at birth",
-#'                         ylab = "Life expectancy at birth",
-#'                         highlight_area = c("England", "Dorset (Cty)"),
-#'                         area = AreaName)
-#' p}
+#' library(dplyr)
+#' df <- create_test_data()
+#'
+#' df_ci <- df %>%
+#'         filter(IndicatorName %in% c("Indicator 1", "Indicator 3")) %>%
+#'         select(IndicatorName, AreaCode, Value) %>%
+#'         pivot_wider(names_from = IndicatorName,
+#'                     values_from = Value) %>%
+#'         rename(Ind1 = `Indicator 1`,
+#'                Ind3 = `Indicator 3`) %>%
+#'         mutate(Ind2 = runif(nrow(.), min = Ind1 * 0.5, max = Ind1 * 1.5))
+#' p <- compare_indicators(df_ci,
+#'                         x = Ind1,
+#'                         y = Ind3,
+#'                         xlab = "Indicator 1 label",
+#'                         ylab = "Indicator 3 label",
+#'                         highlight_area = c("C001", "AC172"),
+#'                         area = AreaCode,
+#'                         add_R2 = TRUE)
+#' p
 #' @export
 compare_indicators <- function(data, x, y,
                                xlab = "", ylab = "",
@@ -371,7 +370,7 @@ compare_indicators <- function(data, x, y,
         }
 
         if (add_R2 == TRUE) {
-                form <- as.formula(paste(y, " ~ ", x)[2])
+                form <- as.formula(paste(as_label(y), " ~ ", as_label(x)))
                 r2 <- summary(lm(form, data = data))
                 r2frame <- data.frame(val = ifelse(r2$r.squared > 0.15,
                                                    paste("R^2:",round2(r2$r.squared, 2)),
@@ -417,25 +416,27 @@ compare_indicators <- function(data, x, y,
 #' @import dplyr
 #' @importFrom rlang quo_text
 #' @examples
-#' \donttest{
-#' # This example is untested because of the time required to retrieve the data
-#' library(fingertipsR)
 #' library(dplyr)
-#' df <- fingertips_data(90366) %>%
-#'             filter(Sex == "Male",
-#'                    Age == "All ages")
-#' p <- trends(df,
+#' df <- create_test_data()
+#'
+#' df_trend <- df %>%
+#'         arrange(IndicatorName) %>%
+#'         mutate(Timeperiod = rep(c("2011", "2012", "2013", "2014", "2015", "2016"),
+#'                                 each = 111))
+#' p <- trends(df_trend,
 #'             timeperiod = Timeperiod,
 #'             value = Value,
-#'             area = AreaName,
-#'             comparator = "England",
-#'             area_name = "Cambridgeshire",
-#'             fill = ComparedtoEnglandvalueorpercentiles,
-#'             title = "Life expectancy at birth",
-#'             subtitle = "Cambridgeshire compared to England",
+#'             area = AreaCode,
+#'             comparator = "C001",
+#'             area_name = "AC142",
+#'             fill = Significance,
+#'             lowerci = LCI,
+#'             upperci = UCI,
+#'             title = "Trend compared to country",
+#'             subtitle = "For area AC142",
 #'             xlab = "Year",
-#'             ylab = "Age (years)")
-#' p}
+#'             ylab = "Value (%)")
+#' p
 #' @export
 trends <- function(data, timeperiod, value,
                    area, comparator, area_name, fill,
@@ -517,9 +518,6 @@ trends <- function(data, timeperiod, value,
 #' @importFrom rlang quo_text
 #' @importFrom scales pretty_breaks
 #' @examples
-#' \donttest{
-#' # This example is untested because of the time required to retrieve the data
-#' library(fingertipsR)
 #' library(dplyr)
 #' agelevels <- c("0-4", "5-9","10-14","15-19",
 #'                "20-24","25-29","30-34",
@@ -527,26 +525,27 @@ trends <- function(data, timeperiod, value,
 #'                "50-54","55-59","60-64",
 #'                "65-69","70-74","75-79",
 #'                "80-84","85-89","90+")
-#' pops <- fingertips_data(92708) %>%
-#'         filter(Timeperiod == "2015" &
-#'                        Sex %in% c("Male", "Female") &
-#'                        Age != "All ages") %>%
-#'         mutate(Age = gsub(" yrs","", Age),
-#'                Age = factor(Age,
-#'                             levels = agelevels)) %>%
-#'         droplevels()
+#' areas <- c("Area 1", "Area 2", "Area 3")
+#' pops <- data.frame(Age = factor(rep(agelevels, length(areas) * 2),
+#'                                 levels = agelevels),
+#'                    Value = rep(sample(1000:3000, length(agelevels), replace = TRUE),
+#'                                length(areas) * 2),
+#'                    Sex = rep(rep(c("Male", "Female"),
+#'                                  each = length(agelevels)), length(areas)),
+#'                    AreaName = rep(areas, each = length(agelevels) * 2))
+#'
 #' p <- population(pops,
 #'                 value = Value,
 #'                 sex = Sex,
 #'                 age = Age,
 #'                 area = AreaName,
-#'                 area_name = "Nottingham",
-#'                 comparator_1 = "England",
-#'                 comparator_2 = "East Midlands region",
+#'                 area_name = "Area 1",
+#'                 comparator_1 = "Area 3",
+#'                 comparator_2 = "Area 2",
 #'                 title = "Age Profile",
-#'                 subtitle = paste(unique(pops$IndicatorName), unique(pops$Timeperiod)),
+#'                 subtitle = "2015/16",
 #'                 xlab = "% of total population")
-#' p}
+#' p
 #' @export
 population <- function(data, value, sex, age,
                        area, area_name, comparator_1, comparator_2,
@@ -655,21 +654,20 @@ population <- function(data, value, sex, age,
 #' @importFrom rlang quo_text
 #' @importFrom stats median quantile
 #' @examples
-#' \donttest{
-#' # This example is untested because of the time required to retrieve the data
-#' library(fingertipsR)
 #' library(dplyr)
-#' df <- fingertips_data(90366) %>%
-#'       filter(Sex == "Male",
-#'       AreaType == "County & UA (pre 4/19)",
-#'       Age == "All ages")
-#' p <- box_plots(df,
+#' df <- create_test_data()
+#'
+#' df_box <- df %>%
+#'         filter(AreaType == "Local") %>%
+#'         arrange(IndicatorName) %>%
+#'         mutate(Timeperiod = rep(c("2011", "2012", "2013", "2014", "2015", "2016"),
+#'                                 each = 100))
+#' p <- box_plots(df_box,
 #'                timeperiod = Timeperiod,
 #'                value = Value,
-#'                title = "Life expectancy at birth",
-#'                subtitle = "Males in Uper Tier Local Authorities England",
-#'                ylab = "Age (years)")
-#' p}
+#'                title = "Title of chart",
+#'                subtitle = "Boxplot over time",
+#'                ylab = "Proportion (%)")
 #' @export
 box_plots <- function(data, timeperiod, value,
                       title = "", subtitle = "",
@@ -713,6 +711,7 @@ box_plots <- function(data, timeperiod, value,
                                  y = middle,
                                  yend = middle),
                              colour="red", size = 1)
+        return(boxplots)
 
 }
 
@@ -725,8 +724,8 @@ box_plots <- function(data, timeperiod, value,
 #'   from ONS API
 #' @param type string; the output map required. Can be "static" or "interactive"
 #' @param ons_api string; GeoJSON address provided from the ONS geography portal
-#' @param copyright_size number; determine size of the copyright text
-#' @param copyright_year number (length 4) or Date class; the copyright year
+#' @param copyright_size number; fix the size of the copyright text
+#' @param copyright_year number (length 4 characters) or Date class; the copyright year
 #'   displayed at bottom of the map. Applies to static maps only
 #' @param name_for_label if interactive map, name of field containing area names
 #'   to be used for label (unquoted) - optional
@@ -739,38 +738,30 @@ box_plots <- function(data, timeperiod, value,
 #' @importFrom geojsonio geojson_read
 #' @importFrom leaflet colorFactor leaflet addTiles addPolygons addLegend
 #' @importFrom stats setNames
-#' @importFrom fingertipsR fingertips_data
 #' @importFrom sf st_as_sf
 #' @examples
-#' \donttest{
-#' # This example is untested because of the time required to retrieve the data
-#' library(fingertipsR)
-#' library(dplyr)
-#' df <- fingertips_data(90366) %>%
-#'         filter(Sex == "Male" ,
-#'                AreaType == "County & UA (pre 4/19)",
-#'                Timeperiod == "2014 - 16",
-#'                Age == "All ages")
 #' ons_api <- "https://opendata.arcgis.com/datasets/687f346f5023410ba86615655ff33ca9_4.geojson"
 #'
-#' p <- map(df,
+#' p <- map(mapdata,
 #'          ons_api = ons_api,
 #'          area_code = AreaCode,
-#'          fill = ComparedtoEnglandvalueorpercentiles,
-#'          title = "Life expectancy at birth",
-#'          subtitle = "Males in Upper Tier Local Authorities England",
-#'          copyright_year = 2018)
+#'          fill = Significance,
+#'          title = "Map example",
+#'          subtitle = "An indicator for Upper Tier Local Authorities England",
+#'          copyright_year = 2019)
+#'
+#' p
 #'
 #' ## For an interactive (leaflet) map
-#' p <- map(df,
+#' p <- map(mapdata,
 #'          ons_api = ons_api,
 #'          area_code = AreaCode,
-#'          fill = ComparedtoEnglandvalueorpercentiles,
+#'          fill = Significance,
 #'          type = "interactive",
 #'          value = Value,
 #'          name_for_label = AreaName,
-#'          title = "Life expectancy at birth<br>Males within UTLAs in England")
-#' p}
+#'          title = "An indicator for Upper Tier<br>Local Authorities England")
+#' p
 #' @export
 map <- function(data, ons_api, area_code, fill, type = "static", value, name_for_label,
                 title = "", subtitle = "", copyright_size = 4, copyright_year = Sys.Date()) {
@@ -838,8 +829,8 @@ map <- function(data, ons_api, area_code, fill, type = "static", value, name_for
                         data <- data %>%
                                 mutate(!!quo_name(fill) :=
                                                factor(!!fill,
-                                                      levels = names(ftipspal)))
-                        factpal <- colorFactor(ftipspal,
+                                                      levels = levels(!!fill)))
+                        factpal <- colorFactor(ftipspal[levels(pull(data, !!fill))],
                                                domain = pull(data, !!fill),
                                                ordered = TRUE)
                         data <- data %>%
@@ -985,33 +976,7 @@ map <- function(data, ons_api, area_code, fill, type = "static", value, name_for
 #' @importFrom stringr str_trim
 #' @importFrom lemon facet_rep_grid
 #' @examples
-#' \donttest{
-#' # This example is untested because of the time required to retrieve the data
-#' library(fingertipsR)
-#' library(dplyr)
-#' df <- fingertips_data(DomainID = 1938133222, rank = TRUE) %>%
-#'            filter(Timeperiod == "2016")
-#' p <- area_profiles(df,
-#'                    value = Value,
-#'                    count = Count,
-#'                    area_code = AreaCode,
-#'                    local_area_code = "E06000020",
-#'                    indicator = IndicatorName,
-#'                    timeperiod = Timeperiod,
-#'                    polarity = Polarity,
-#'                    significance = ComparedtoEnglandvalueorpercentiles,
-#'                    area_type = AreaType,
-#'                    cols = "fingertips",
-#'                    median_line_area_code = "E92000001",
-#'                    comparator_area_code = "E12000005",
-#'                    datatable = TRUE,
-#'                    relative_domain_text_size = 0.75,
-#'                    relative_text_size = 1.2,
-#'                    bar_width = 0.68,
-#'                    indicator_label_nudgex = -0.5)
-#' p}
-#'
-#' ## or an example with differing decimal places for individual indicators
+#' ## An example with differing decimal places for individual indicators
 #'
 #' library(dplyr)
 #' df <- create_test_data() %>%
@@ -1041,7 +1006,7 @@ map <- function(data, ons_api, area_code, fill, type = "static", value, name_for
 #'                         dps = NA)
 #' full_p
 #'
-#' ## or an example with domains and non-default indicator ordering
+#' ## An example with domains and non-default indicator ordering
 #'
 #' df <- create_test_data()
 #' label_order <- c(1, 2, 4, 3, 6, 5)
@@ -1284,7 +1249,9 @@ area_profiles <- function(data,
                                            limits = lims,
                                            labels = header_labels,
                                            expand = c(0, 0)) +
-                        geom_text(aes(label = label, y = y),
+                        geom_text(data = dfrescaled$bars[!dfrescaled$bars$GraphPoint %in%
+                                                                 c("Q75", "Q25"), ],
+                                  aes(label = label, y = y),
                                   col = "black",
                                   size = 2.5 * relative_text_size,
                                   lineheight = datatable_line_height,
